@@ -347,9 +347,8 @@ class Dotfiles:
     @property
     def modified_unstaged(self) -> List[str]:
         """Returns all files with unstaged modifications or Deletions."""
-        mods = [
-            line[3:] for line in self.short_status if line[:2] in [" M", " D", "MM"]
-        ]
+        mod_codes = [" M", " D", "MM", "AM"]
+        mods = [line[3:] for line in self.short_status if line[:2] in mod_codes]
         renamed_mods = [s.split(" -> ")[1] for s in self.short_status if s[:2] == "RM"]
         return sorted(renamed_mods + mods)
 
